@@ -1076,7 +1076,7 @@ func (c *Client) Receive() (err error) {
 				conn, banner2, externalIP, errConn := tcp.ConnectToTCPServer(serverTry, c.Options.RelayPassword, c.Options.RoomName, 500*time.Millisecond)
 				if errConn != nil {
 					log.Debug(errConn)
-					log.Debugf("could not connect to " + serverTry)
+					log.Debug("could not connect to " + serverTry)
 					continue
 				}
 				log.Debugf("local connection established to %s", serverTry)
